@@ -45,9 +45,10 @@ class SimpleRestApp(object):
 class SimpleRestResource(object):
     def __init__(self, rest_instance, prefix=''):
         self.app = rest_instance.app
-        for method_name, instance in inspect.getmembers(self):
+        for method_name, cls_instance in inspect.getmembers(self.__class__):
             if method_name.startswith('__'):
                 continue
+            instance = getattr(self, method_name)
             if not hasattr(instance, 'path') or not hasattr(instance, 'method'):
                 raise Exception('You must use @rest(path, method) for all method of your cls')
             setattr(self, method_name, rest_instance(prefix + instance.path, instance.method)(instance))
@@ -57,4 +58,4 @@ def rest(path, method):
         fn.path = path
         fn.method = method
         return fn
-    return wrapper
\ No newline at end of file
+    return wrapper
